<?php
/**
 * @file       divalign2/common.php
 * @brief      Common functions for the divalign2 plugin
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @version    2.2
 * @author     Luis Machuca B. <luis.machuca [at] gulix.cl>
 */

/* must be invoked from syntax/*.php
 */
if(!defined('DOKU_INC')) die();
if(!defined('DOKU_PLUGIN')) die();

/**
 * @class DW_common_divalign2
 * @brief Common interface for divalign2
 */
class DW_common_divalign2 {

static public function getInfo ($mode=false) {
    $component = ($mode !== false) ? "Controls $mode-alignment in DokuWiki" : "Controls alignment";
    return array(
      'author' => 'Luis Machuca Bezzaza',
      'email'  => 'luis.machuca[at]gulix.cl',
      'date'   => @file_get_contents(DOKU_PLUGIN.'divalign2/VERSION'),
      'name'   => 'divalign2',
      'desc'   => $component,
      'url'    => 'http://www.dokuwiki.org/plugin:divalign2',
      );
    }

static public function getSort () {
    return 180;
    }

static public function getType () {
    return 'container';
    }

static public function getAllowedTypes() { 
    return array( 
         'container', 'substition', 'protected', 
         'disabled', 'formatting', 'paragraphs'); 
    }

static public function getPType () {
    return 'stack';
    }


static public function render ($mode, &$renderer, $data) {
    list($align,$state,$pos) = $data;
    if ($mode == 'xhtml') {
      switch ($state) {
        case DOKU_LEXER_ENTER: {
          if ($align) { 
            $renderer->doc .= '<div class="divalign-'.$align.'">'; 
            }
          break;
          }
        case DOKU_LEXER_EXIT : {
          $renderer->doc .= '</div>'. DW_LF;
          break;
          }
        } // end switch
      return true;
      } // end if ($mode == 'xhtml')

    else if ($mode == 'odt' ) {
      $Align = ucfirst ($align);
      static $center_defined= false;
      $st = <<<EOF
<style:style style:name="Text.Divalign.$Align" style:display-name="Text.Divalign.$Align" style:family="paragraph" style:parent-style-name="Text_20_body">
    <style:paragraph-properties fo:text-align="$align" style:justify-single-word="false" />
    </style:style>

EOF;

      $renderer->autostyles["Text.Divalign.$Align"]= $st;
      $center_defined= true;
      switch ($state) {
        case DOKU_LEXER_ENTER: {
          $renderer->doc.= "<text:p text:style-name=\"Text.Divalign.$Align\">";
          break;
          }
        case DOKU_LEXER_EXIT: {
          $renderer->doc.= '</text:p>';
          break;
          }
        } // end switch
      return true;
    }

    else if ($mode == 'text' ) {
      switch ($state) {
        case DOKU_LEXER_ENTER: {
          $renderer->doc .= DW_LF;
          break;
          }
        case DOKU_LEXER_EXIT : {
          $renderer->doc .= DW_LF;
          break;
          }
        } // end switch
      return true;
      } // end if ($mode == 'text')

    return false;
    } // end function

} // end class


